<?php
namespace Elementor;

class BPAC_Widget extends Widget_Base {
	
	public function get_name() {
		return 'bpac-forms';
	}

    public function get_style_depends() {
       wp_enqueue_style( 'bpac-custom', plugins_url( 'assets/css/custom.css', __FILE__ ), array(), '1.0.0', 'all' );
       wp_enqueue_style( 'pignose-calendar', plugins_url( 'assets/css/pignose.calendar.min.css', __FILE__ ), array(), '1.0.0', 'all' );
        return [
            'bpac-custom',
            'pignose-calendar',
        ];
    }
	
	public function get_title() {
		return esc_html__('Booking Property Availability Checker', 'bpac');
	}
	
	public function get_icon() {
		return 'eicon-form-horizontal';
	}
	
	public function get_categories() {
		return [ 'modeltheme-widgets' ];
	}

   protected function register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'General Options', 'bpac' ),
            ]
        );
        $this->add_control(
            'version',
            [
                'label' => esc_html__( 'Version', 'bpac' ),
                'label_block' => true,
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'v1'    => esc_html__( 'V1', 'bpac' ),
                    'v2'    => esc_html__( 'V2', 'bpac' ),
                ],
                'default' => 'v1',
            ]
        );
        $this->add_control(
            'property_link',
            [
                'label' => esc_html__( 'Property Link', 'bpac' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Your property link', 'bpac' ),
                'default' => 'https://www.booking.com/hotel/ro/campeador-inn.ro.html',
            ]
        );
        $this->add_control(
            'max_guests',
            [
                'label' => esc_html__( 'Max Guests', 'bpac' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 10,
                'step' => 1,
            ]
        );
        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'bpac'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('ex: Find your property', 'bpac'),
                'default' => esc_html__('Find your property', 'bpac'),
            ]
        );
        $this->add_control(
            'submit_button_label',
            [
                'label' => esc_html__('Submit Button Label', 'bpac'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('ex: Submit', 'bpac'),
                'default' => esc_html__('Submit', 'bpac'),
            ]
        );
        $this->add_control(
            'powered_by',
            [
                'label' => esc_html__( 'Powered By', 'bpac' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'On', 'bpac' ),
                'label_off' => esc_html__( 'Off', 'bpac' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'style_section',
            [
                'label' => esc_html__( 'Style Options', 'bpac' ),
            ]
        );
        $this->add_control(
            'color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Button Text Color', 'bpac' ),
                'selectors' => [
                    '{{WRAPPER}} .bpac-submit' => 'color: {{VALUE}} !important',
                ],
                'default' => '#fff',
            ]
        );
        $this->add_control(
            'color_hover',
            [
                'label' => esc_html__( 'Button Text Color Hover', 'bpac' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bpac-submit:hover' => 'color: {{VALUE}} !important',
                ],
                'default' => '#fff',
            ]
        );
        $this->add_control(
            'bg_color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Button Background Color', 'bpac' ),
                 'selectors' => [
                    '{{WRAPPER}} .bpac-submit' => 'background-color: {{VALUE}} !important',
                ],
                'default' => '#0071C2',
            ]
        );
        $this->add_control(
            'bg_color_hover',
            [
                'label' => esc_html__( 'Button Background Color Hover', 'bpac' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bpac-submit:hover' => 'background-color: {{VALUE}} !important',
                ],
                'default' => '#00487A',
            ]
        );
        $this->add_control(
            'bg_form',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Form Background', 'bpac' ),
                 'selectors' => [
                    '{{WRAPPER}} .mt-booking-property-availability-checker-form' => 'background-color: {{VALUE}} !important',
                ],
                'default' => '#fff',
            ]
        );
        $this->add_control(
            'color_label',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Label Text Color', 'bpac' ),
                 'selectors' => [
                    '{{WRAPPER}} .bpac_row .bpac_input_wrapper label, {{WRAPPER}} .bpac-date-wrapper label ' => 'color: {{VALUE}} !important',
                ],
                'default' => '#000',
            ]
        );
        $this->end_controls_section();

    }
	
	protected function render() {
        $settings 					= $this->get_settings_for_display();
        $version                    = $settings['version'];
        $property_link              = $settings['property_link'];
        $max_guests                 = $settings['max_guests'];
        $submit_button_label        = $settings['submit_button_label'];
        $color                      = $settings['color'];
        $color_hover                = $settings['color_hover'];
        $bg_color                   = $settings['bg_color'];
        $bg_color_hover             = $settings['bg_color_hover'];
        $bg_form                    = $settings['bg_form'];
        $color_label                = $settings['color_label'];
        $powered_by                 = $settings['powered_by'];
        $title                      = $settings['title'];

        $shortcode_content = '';
        $shortcode_content .= do_shortcode('[bpac-builder-shortcode 
            version="'.esc_attr($version).'" 
            property_link="'.esc_attr($property_link).'"  
            max_guests="'.esc_attr($max_guests).'" 
            color="'.esc_attr($color).'" 
            color_hover="'.esc_attr($color_hover).'" 
            bg_color="'.esc_attr($bg_color).'" 
            bg_color_hover="'.esc_attr($bg_color_hover).'" 
            bg_form="'.esc_attr($bg_form).'" 
            color_label="'.esc_attr($color_label).'" 
            powered_by="'.esc_attr($powered_by).'" 
            title="'.esc_attr($title).'" 
            submit_button_label="'.esc_attr($submit_button_label).'"]');

        echo  do_shortcode($shortcode_content);
	}
	
	protected function content_template() {

    }
}
